==> reactjs-bootstrap-table-1.0.1.tgz: package/lib/ColumnSort.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Glyph = require('./Glyph');

var _Glyph2 = _interopRequireDefault(_Glyph);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function (tableComponent) {

  function noop() {}

  var callback = tableComponent.props.onSort || noop;

  // icon components
  var up = _react2.default.createElement(_Glyph2.default, { icon: 'triangle-top' });
  var down = _react2.default.createElement(_Glyph2.default, { icon: 'triangle-bottom' });
  var none = _react2.default.createElement('span', null);

  // current column state has name: 'asc', 'desc', or 'default' and icon.
  var columns = {};

  tableComponent.props.columns.forEach(function (col) {
    if (col.sort) {
      // initial sort state
      columns[col.name] = {
        state: 'none',
        icon: none
      };
    }
  });

  // column clicked on, update the sort state and trigger the
  // sort callback.
  this.sort = function (colName) {
    var next = void 0,
        icon = void 0;
    if (columns[colName]) {
      switch (columns[colName].state) {
        case 'none':
          next = 'asc';
          icon = up;
          break;

        case 'desc':
          next = 'none';
          icon = none;
          break;

        case 'asc':
          next = 'desc';
          icon = down;
          break;
      }
      columns[colName].state = next;
      columns[colName].icon = icon;
      callback(colName, next);
      return true;
    } else {
      return false;
    }
  };

  this.getIcon = function (colName) {
    var column = columns[colName];
    if (column) return column.icon;
    return none;
  };
};

==> reactjs-bootstrap-table-1.0.6.tgz: package/lib/ColumnSort.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Glyph = require('./Glyph');

var _Glyph2 = _interopRequireDefault(_Glyph);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function (tableComponent) {

  function noop() {}

  var callback = tableComponent.props.onSort || noop;

  // icon components
  var up = _react2.default.createElement(_Glyph2.default, { icon: 'triangle-top' });
  var down = _react2.default.createElement(_Glyph2.default, { icon: 'triangle-bottom' });
  var none = _react2.default.createElement('span', null);

  // current column state has name: 'asc', 'desc', or 'default' and icon.
  var columns = {};

  tableComponent.columns.forEach(function (col) {
    if (col.sort) {
      // initial sort state
      columns[col.name] = {
        state: 'none',
        icon: none
      };
    }
  });

  // column clicked on, update the sort state and trigger the
  // sort callback.
  this.sort = function (colName) {
    var next = void 0,
        icon = void 0;
    if (columns[colName]) {
      switch (columns[colName].state) {
        case 'none':
          next = 'asc';
          icon = up;
          break;

        case 'desc':
          next = 'none';
          icon = none;
          break;

        case 'asc':
          next = 'desc';
          icon = down;
          break;
      }
      columns[colName].state = next;
      columns[colName].icon = icon;
      callback(colName, next);
      return true;
    } else {
      return false;
    }
  };

  this.getIcon = function (colName) {
    var column = columns[colName];
    if (column) return column.icon;
    return none;
  };
};
